@@ -42,7 +42,7 @@ class Fraction(object):
         return a * aa * bb
 
     def __init__(self, _numerator, denominator):
-        if denominator == 0:
+        if denominator == 0: 
             raise CalculateError("fatal error:Denominator = 0")
         self._numerator = _numerator
         self.denominator = denominator
@@ -69,7 +69,7 @@ class Fraction(object):
         return self._numerator, self.denominator
 
     def reduction(self, factor=None):
-        if factor == None:
+        if factor is None:
             factor = self.__gongyue(self._numerator, self.denominator)
         if self._numerator / factor != floor(self._numerator / factor) or self.denominator / factor != floor(
                 self.denominator / factor):
@@ -122,7 +122,7 @@ class VulgarFraction(Fraction):
     def toMixed(self):
         temp = MixedFraction(0, 0, self.denominator)
         temp.numerator = self.numerator
-        return temp 
+        return temp
 
     @property
     def numerator(self):
@@ -237,11 +237,11 @@ class VulgarFraction(Fraction):
             otr = fra.common(other)
         return fra.numerator < otr.numerator
 
-    def irec(self): # 你这个是直接赋值，return的是None啊
+    def irec(self):  # 你这个是直接赋值，return的是None啊
         self.numerator, self.denominator = self.denominator, self.numerator
 
     def rec(self):  # 有返回值的倒数
-        return VulgarFraction(self.denominator,self.numerator)
+        return VulgarFraction(self.denominator, self.numerator)
 
     def __pow__(self, other):
         if isinstance(other, (VulgarFraction, int, float)):
@@ -384,14 +384,14 @@ class MixedFraction(Fraction):
                             self.denominator).toVulgar()
         return (fra / other).toMixed()
 
-    def __rsub__(self,other):
+    def __rsub__(self, other):
 
-        return -(self-other)
-    
-    def __rtruediv__(self,other):
-        return (self/other).rec()
+        return -(self - other)
 
-    def __call__(self,integer,numerator,denominator,*args):
+    def __rtruediv__(self, other):
+        return (self / other).rec()
+
+    def __call__(self, integer, numerator, denominator, *args):
         if args:
             raise CalculateError('only 3 arguments')
         self.integer = integer
@@ -399,8 +399,25 @@ class MixedFraction(Fraction):
         self.numerator = numerator
 
 
+class ComplexFraction(Fraction):
+    def __init__(self, numerator: complex, denominator: complex):
+        super().__init__(numerator, denominator)
+        self.numerator = numerator
+        self.denominator = denominator
+
+    def common(self, other):
+        def is_int(number):
+            return abs(number-round(number)) == 0
+        
+        def complex_to_complex_fraction(number):
+            pass  # 没做完
+        
+        def is_complex_int(number:complex):
+            return is_int(number.imag) and is_int(number.real)
+
+
 if __name__ == "__main__":
     a = VulgarFraction(10, 20)
     print(
-        format(a,"1")
+        format(a, "1")
     )
